==> dovecot-1.1.7-i586-P1.tgz: install/doinst.sh <==
( if [ ! dovecot:x:32: ]; then
    /usr/sbin/groupadd -g 32 dovecot
  fi
  if [ ! dovecot:x:33:32::/dev/null:/bin/true ]; then
    /usr/sbin/useradd -u 33 -g dovecot -s /bin/true -d /dev/null dovecot
  fi
)

( cd etc/dovecot
  if [ ! -f /etc/dovecot/dovecot.conf ]; then
    cat > /etc/dovecot/dovecot.conf << EOF2
protocols = imap pop3
disable_plaintext_auth = no
mail_location = mbox:~/mail:INBOX=/var/mail/%u
ssl_disable = yes
protocol imap {
}
protocol pop3 {
}
auth default {
  mechanisms = plain
  passdb pam {
    args = plamo-default
  }
  userdb passwd {
  }
  user = root
  socket listen {
    client {
      path = /var/spool/postfix/private/auth
      mode = 0660
      user = postfix
      group = postfix
    }
  }
}
EOF2
  fi
)
( cd usr/lib/dovecot/pop3 ; rm -rf lib20_fts_plugin.so )
( cd usr/lib/dovecot/pop3 ; ln -sf ../lib20_fts_plugin.so lib20_fts_plugin.so )
( cd usr/lib/dovecot/pop3 ; rm -rf lib21_fts_squat_plugin.so )
( cd usr/lib/dovecot/pop3 ; ln -sf ../lib21_fts_squat_plugin.so lib21_fts_squat_plugin.so )
( cd usr/lib/dovecot/pop3 ; rm -rf lib20_mail_log_plugin.so )
( cd usr/lib/dovecot/pop3 ; ln -sf ../lib20_mail_log_plugin.so lib20_mail_log_plugin.so )
( cd usr/lib/dovecot/pop3 ; rm -rf lib20_zlib_plugin.so )
( cd usr/lib/dovecot/pop3 ; ln -sf ../lib20_zlib_plugin.so lib20_zlib_plugin.so )
( cd usr/lib/dovecot/pop3 ; rm -rf lib02_lazy_expunge_plugin.so )
( cd usr/lib/dovecot/pop3 ; ln -sf ../lib02_lazy_expunge_plugin.so lib02_lazy_expunge_plugin.so )
( cd usr/lib/dovecot/pop3 ; rm -rf lib20_expire_plugin.so )
( cd usr/lib/dovecot/pop3 ; ln -sf ../lib20_expire_plugin.so lib20_expire_plugin.so )
( cd usr/lib/dovecot/pop3 ; rm -rf lib20_convert_plugin.so )
( cd usr/lib/dovecot/pop3 ; ln -sf ../lib20_convert_plugin.so lib20_convert_plugin.so )
( cd usr/lib/dovecot/pop3 ; rm -rf lib10_quota_plugin.so )
( cd usr/lib/dovecot/pop3 ; ln -sf ../lib10_quota_plugin.so lib10_quota_plugin.so )
( cd usr/lib/dovecot/pop3 ; rm -rf lib20_mbox_snarf_plugin.so )
( cd usr/lib/dovecot/pop3 ; ln -sf ../lib20_mbox_snarf_plugin.so lib20_mbox_snarf_plugin.so )
( cd usr/lib/dovecot/lda ; rm -rf lib20_fts_plugin.so )
( cd usr/lib/dovecot/lda ; ln -sf ../lib20_fts_plugin.so lib20_fts_plugin.so )
( cd usr/lib/dovecot/lda ; rm -rf lib11_trash_plugin.so )
( cd usr/lib/dovecot/lda ; ln -sf ../lib11_trash_plugin.so lib11_trash_plugin.so )
( cd usr/lib/dovecot/lda ; rm -rf lib21_fts_squat_plugin.so )
( cd usr/lib/dovecot/lda ; ln -sf ../lib21_fts_squat_plugin.so lib21_fts_squat_plugin.so )
( cd usr/lib/dovecot/lda ; rm -rf lib20_mail_log_plugin.so )
( cd usr/lib/dovecot/lda ; ln -sf ../lib20_mail_log_plugin.so lib20_mail_log_plugin.so )
( cd usr/lib/dovecot/lda ; rm -rf lib01_acl_plugin.so )
( cd usr/lib/dovecot/lda ; ln -sf ../lib01_acl_plugin.so lib01_acl_plugin.so )
( cd usr/lib/dovecot/lda ; rm -rf lib20_expire_plugin.so )
( cd usr/lib/dovecot/lda ; ln -sf ../lib20_expire_plugin.so lib20_expire_plugin.so )
( cd usr/lib/dovecot/lda ; rm -rf lib20_convert_plugin.so )
( cd usr/lib/dovecot/lda ; ln -sf ../lib20_convert_plugin.so lib20_convert_plugin.so )
( cd usr/lib/dovecot/lda ; rm -rf lib10_quota_plugin.so )
( cd usr/lib/dovecot/lda ; ln -sf ../lib10_quota_plugin.so lib10_quota_plugin.so )
( cd usr/lib/dovecot/imap ; rm -rf lib20_fts_plugin.so )
( cd usr/lib/dovecot/imap ; ln -sf ../lib20_fts_plugin.so lib20_fts_plugin.so )
( cd usr/lib/dovecot/imap ; rm -rf lib11_trash_plugin.so )
( cd usr/lib/dovecot/imap ; ln -sf ../lib11_trash_plugin.so lib11_trash_plugin.so )
( cd usr/lib/dovecot/imap ; rm -rf lib21_fts_squat_plugin.so )
( cd usr/lib/dovecot/imap ; ln -sf ../lib21_fts_squat_plugin.so lib21_fts_squat_plugin.so )
( cd usr/lib/dovecot/imap ; rm -rf lib20_mail_log_plugin.so )
( cd usr/lib/dovecot/imap ; ln -sf ../lib20_mail_log_plugin.so lib20_mail_log_plugin.so )
( cd usr/lib/dovecot/imap ; rm -rf lib01_acl_plugin.so )
( cd usr/lib/dovecot/imap ; ln -sf ../lib01_acl_plugin.so lib01_acl_plugin.so )
( cd usr/lib/dovecot/imap ; rm -rf lib20_zlib_plugin.so )
( cd usr/lib/dovecot/imap ; ln -sf ../lib20_zlib_plugin.so lib20_zlib_plugin.so )
( cd usr/lib/dovecot/imap ; rm -rf lib02_lazy_expunge_plugin.so )
( cd usr/lib/dovecot/imap ; ln -sf ../lib02_lazy_expunge_plugin.so lib02_lazy_expunge_plugin.so )
( cd usr/lib/dovecot/imap ; rm -rf lib20_expire_plugin.so )
( cd usr/lib/dovecot/imap ; ln -sf ../lib20_expire_plugin.so lib20_expire_plugin.so )
( cd usr/lib/dovecot/imap ; rm -rf lib20_convert_plugin.so )
( cd usr/lib/dovecot/imap ; ln -sf ../lib20_convert_plugin.so lib20_convert_plugin.so )
( cd usr/lib/dovecot/imap ; rm -rf lib10_quota_plugin.so )
( cd usr/lib/dovecot/imap ; ln -sf ../lib10_quota_plugin.so lib10_quota_plugin.so )
( cd usr/lib/dovecot/imap ; rm -rf lib20_mbox_snarf_plugin.so )
( cd usr/lib/dovecot/imap ; ln -sf ../lib20_mbox_snarf_plugin.so lib20_mbox_snarf_plugin.so )

==> dovecot-1.1.15-i586-P1.tgz: install/doinst.sh <==
( if [ ! `/bin/grep dovecot /etc/group` ]; then
    /usr/sbin/groupadd -g 32 dovecot
  fi
  if [ ! `/bin/grep dovecot /etc/passwd` ]; then
    /usr/sbin/useradd -u 33 -g dovecot -s /bin/true -d /dev/null dovecot
  fi
)

( cd etc/dovecot
  if [ ! -f /etc/dovecot/dovecot.conf ]; then
    cat > /etc/dovecot/dovecot.conf << EOF2
protocols = imap pop3
disable_plaintext_auth = no
mail_location = mbox:~/mail:INBOX=/var/mail/%u
ssl_disable = yes
protocol imap {
}
protocol pop3 {
}
auth default {
  mechanisms = plain
  passdb pam {
    args = plamo-default
  }
  userdb passwd {
  }
  user = root
  socket listen {
    client {
      path = /var/spool/postfix/private/auth
      mode = 0660
      user = postfix
      group = postfix
    }
  }
}
EOF2
  fi
)
( cd usr/lib/dovecot/pop3 ; rm -rf lib20_convert_plugin.so )
( cd usr/lib/dovecot/pop3 ; ln -sf ../lib20_convert_plugin.so lib20_convert_plugin.so )
( cd usr/lib/dovecot/pop3 ; rm -rf lib20_expire_plugin.so )
( cd usr/lib/dovecot/pop3 ; ln -sf ../lib20_expire_plugin.so lib20_expire_plugin.so )
( cd usr/lib/dovecot/pop3 ; rm -rf lib10_quota_plugin.so )
( cd usr/lib/dovecot/pop3 ; ln -sf ../lib10_quota_plugin.so lib10_quota_plugin.so )
( cd usr/lib/dovecot/pop3 ; rm -rf lib20_zlib_plugin.so )
( cd usr/lib/dovecot/pop3 ; ln -sf ../lib20_zlib_plugin.so lib20_zlib_plugin.so )
( cd usr/lib/dovecot/pop3 ; rm -rf lib20_fts_plugin.so )
( cd usr/lib/dovecot/pop3 ; ln -sf ../lib20_fts_plugin.so lib20_fts_plugin.so )
( cd usr/lib/dovecot/pop3 ; rm -rf lib20_mbox_snarf_plugin.so )
( cd usr/lib/dovecot/pop3 ; ln -sf ../lib20_mbox_snarf_plugin.so lib20_mbox_snarf_plugin.so )
( cd usr/lib/dovecot/pop3 ; rm -rf lib20_mail_log_plugin.so )
( cd usr/lib/dovecot/pop3 ; ln -sf ../lib20_mail_log_plugin.so lib20_mail_log_plugin.so )
( cd usr/lib/dovecot/pop3 ; rm -rf lib21_fts_squat_plugin.so )
( cd usr/lib/dovecot/pop3 ; ln -sf ../lib21_fts_squat_plugin.so lib21_fts_squat_plugin.so )
( cd usr/lib/dovecot/pop3 ; rm -rf lib02_lazy_expunge_plugin.so )
( cd usr/lib/dovecot/pop3 ; ln -sf ../lib02_lazy_expunge_plugin.so lib02_lazy_expunge_plugin.so )
( cd usr/lib/dovecot/lda ; rm -rf lib20_convert_plugin.so )
( cd usr/lib/dovecot/lda ; ln -sf ../lib20_convert_plugin.so lib20_convert_plugin.so )
( cd usr/lib/dovecot/lda ; rm -rf lib20_expire_plugin.so )
( cd usr/lib/dovecot/lda ; ln -sf ../lib20_expire_plugin.so lib20_expire_plugin.so )
( cd usr/lib/dovecot/lda ; rm -rf lib10_quota_plugin.so )
( cd usr/lib/dovecot/lda ; ln -sf ../lib10_quota_plugin.so lib10_quota_plugin.so )
( cd usr/lib/dovecot/lda ; rm -rf lib20_fts_plugin.so )
( cd usr/lib/dovecot/lda ; ln -sf ../lib20_fts_plugin.so lib20_fts_plugin.so )
( cd usr/lib/dovecot/lda ; rm -rf lib20_mail_log_plugin.so )
( cd usr/lib/dovecot/lda ; ln -sf ../lib20_mail_log_plugin.so lib20_mail_log_plugin.so )
( cd usr/lib/dovecot/lda ; rm -rf lib21_fts_squat_plugin.so )
( cd usr/lib/dovecot/lda ; ln -sf ../lib21_fts_squat_plugin.so lib21_fts_squat_plugin.so )
( cd usr/lib/dovecot/lda ; rm -rf lib01_acl_plugin.so )
( cd usr/lib/dovecot/lda ; ln -sf ../lib01_acl_plugin.so lib01_acl_plugin.so )
( cd usr/lib/dovecot/lda ; rm -rf lib11_trash_plugin.so )
( cd usr/lib/dovecot/lda ; ln -sf ../lib11_trash_plugin.so lib11_trash_plugin.so )
( cd usr/lib/dovecot/imap ; rm -rf lib20_convert_plugin.so )
( cd usr/lib/dovecot/imap ; ln -sf ../lib20_convert_plugin.so lib20_convert_plugin.so )
( cd usr/lib/dovecot/imap ; rm -rf lib20_expire_plugin.so )
( cd usr/lib/dovecot/imap ; ln -sf ../lib20_expire_plugin.so lib20_expire_plugin.so )
( cd usr/lib/dovecot/imap ; rm -rf lib10_quota_plugin.so )
( cd usr/lib/dovecot/imap ; ln -sf ../lib10_quota_plugin.so lib10_quota_plugin.so )
( cd usr/lib/dovecot/imap ; rm -rf lib20_zlib_plugin.so )
( cd usr/lib/dovecot/imap ; ln -sf ../lib20_zlib_plugin.so lib20_zlib_plugin.so )
( cd usr/lib/dovecot/imap ; rm -rf lib20_fts_plugin.so )
( cd usr/lib/dovecot/imap ; ln -sf ../lib20_fts_plugin.so lib20_fts_plugin.so )
( cd usr/lib/dovecot/imap ; rm -rf lib20_mbox_snarf_plugin.so )
( cd usr/lib/dovecot/imap ; ln -sf ../lib20_mbox_snarf_plugin.so lib20_mbox_snarf_plugin.so )
( cd usr/lib/dovecot/imap ; rm -rf lib20_mail_log_plugin.so )
( cd usr/lib/dovecot/imap ; ln -sf ../lib20_mail_log_plugin.so lib20_mail_log_plugin.so )
( cd usr/lib/dovecot/imap ; rm -rf lib21_fts_squat_plugin.so )
( cd usr/lib/dovecot/imap ; ln -sf ../lib21_fts_squat_plugin.so lib21_fts_squat_plugin.so )
( cd usr/lib/dovecot/imap ; rm -rf lib01_acl_plugin.so )
( cd usr/lib/dovecot/imap ; ln -sf ../lib01_acl_plugin.so lib01_acl_plugin.so )
( cd usr/lib/dovecot/imap ; rm -rf lib11_trash_plugin.so )
( cd usr/lib/dovecot/imap ; ln -sf ../lib11_trash_plugin.so lib11_trash_plugin.so )
( cd usr/lib/dovecot/imap ; rm -rf lib02_lazy_expunge_plugin.so )
( cd usr/lib/dovecot/imap ; ln -sf ../lib02_lazy_expunge_plugin.so lib02_lazy_expunge_plugin.so )
